Message

Struct Message 

pub struct Message {
    pub(crate) cmsg: MQTTAsync_message,
    pub(crate) data: Pin<Box<MessageData>>,
}
A Message represents all the information passed in an MQTT PUBLISH packet. This is the primary data transfer mechanism.

Fields

cmsg: MQTTAsync_messagedata: Pin<Box<MessageData>>

Implementations



impl Message

pub fn new<S, V, Q>(topic: S, payload: V, qos: Q) -> Message
where S: Into<String>, V: Into<Vec<u8>>, Q: Into<QoS>,

Creates a new message.

Arguments
  • topic The topic on which the message is published.
  • payload The binary payload of the message
  • qos The quality of service for message delivery (0, 1, or 2)

pub fn new_retained<S, V, Q>(topic: S, payload: V, qos: Q) -> Message
where S: Into<String>, V: Into<Vec<u8>>, Q: Into<QoS>,

Creates a new message that will be retained by the broker. This creates a message with the ‘retained’ flag set.

Arguments
  • topic The topic on which the message is published.
  • payload The binary payload of the message
  • qos The quality of service for message delivery (0, 1, or 2)

pub fn topic(&self) -> &str

Gets the topic for the message.

pub fn payload(&self) -> &[u8]

Gets the payload of the message. This returns the payload as a slice.

pub fn payload_str(&self) -> Cow<'_, str>

Gets the payload of the message as a string.

This utilizes the “lossy” style of conversion from the std library. If the contents of the CStr are valid UTF-8 data, this function will return a Cow::Borrowed(&str) with the the corresponding &str slice. Otherwise, it will replace any invalid UTF-8 sequences with U+FFFD REPLACEMENT CHARACTER and return a Cow::Owned(String) with the result.

pub fn qos(&self) -> QoS

Returns the Quality of Service (QOS) for the message.

pub fn retained(&self) -> bool

Gets the ‘retain’ flag for the message.

pub fn properties(&self) -> &Properties

Gets the properties in the message