MessageBuilder

Struct MessageBuilder 

pub struct MessageBuilder {
    topic: String,
    payload: Vec<u8>,
    qos: QoS,
    retained: bool,
    props: Properties,
}
Builder to create a new Message

Fields

topic: Stringpayload: Vec<u8>qos: QoSretained: boolprops: Properties

Implementations



impl MessageBuilder

pub fn new() -> MessageBuilder

Create a new message builder.

pub fn topic<T>(self, topic: T) -> MessageBuilder
where T: Into<String>,

Sets the topic for the message

Arguments
  • topic The topic on which the message should be published.

pub fn payload<V>(self, payload: V) -> MessageBuilder
where V: Into<Vec<u8>>,

Sets the payload for the message

Arguments
  • payload The binary payload of the message

pub fn qos<Q>(self, qos: Q) -> MessageBuilder
where Q: Into<QoS>,

Sets the Quality of Service for the message.

Arguments
  • qos The quality of service for the message.

pub fn retained(self, retained: bool) -> MessageBuilder

Sets whether or not the published message should be retained by the broker.

Arguments
  • retained Set true if the message should be retained by the broker, false if not.

pub fn properties(self, props: Properties) -> MessageBuilder

Sets the collection of properties for the message.

Arguments
  • props The collection of properties to include with the message.

pub fn finalize(self) -> Message

Finalize the builder to create the message.